@@ -4,35 +4,36 @@ conda packages.
 
 from __future__ import annotations
 
-import os
+from pathlib import Path
 
 from .tmpdirs import InTemporaryDirectory
 from .tools import tarbz2todir
 
 
 class InCondaPkg(InTemporaryDirectory):
-    def __init__(self, in_conda_pkg: str) -> None:
+    def __init__(self, in_conda_pkg: Path) -> None:
         """Initialize in-conda-package context manager"""
-        self.in_conda_pkg = os.path.abspath(in_conda_pkg)
+        self.in_conda_pkg = in_conda_pkg.absolute()
         super().__init__()
 
-    def __enter__(self) -> str:
+    def __enter__(self) -> Path:
         tarbz2todir(self.in_conda_pkg, self.name)
         return super().__enter__()
 
 
 class InCondaPkgCtx(InCondaPkg):
-    def __init__(self, in_conda_pkg: str) -> None:
+    def __init__(self, in_conda_pkg: Path) -> None:
         super().__init__(in_conda_pkg)
-        self.path: str | None = None
+        self.path: Path | None = None
 
-    def __enter__(self):
+    def __enter__(self):  # type: ignore[no-untyped-def]
         self.path = super().__enter__()
         return self
 
     def iter_files(self) -> list[str]:
         if self.path is None:
-            raise ValueError("This function should be called from context manager")
-        files = os.path.join(self.path, "info", "files")
+            msg = "This function should be called from context manager"
+            raise ValueError(msg)
+        files = self.path / "info" / "files"
         with open(files) as f:
             return [line.strip() for line in f.readlines()]
